/*
 * Work under Copyright. Licensed under the EUPL.
 * See the project README.md and LICENSE.txt for more information.
 */

package net.dries007.tfc.objects;

import java.util.Arrays;

import net.minecraft.creativetab.CreativeTabs;
import net.minecraft.init.Items;
import net.minecraft.item.ItemStack;
import net.minecraft.util.ResourceLocation;
import net.minecraftforge.fml.common.registry.ForgeRegistries;

import net.dries007.tfc.TerraFirmaCraft;

import static net.dries007.tfc.Constants.MOD_ID;
import static net.minecraft.creativetab.CreativeTabs.CREATIVE_TAB_ARRAY;

public final class CreativeTabsTFC
{
    public static final CreativeTabs CT_ROCK_BLOCKS = new CT("rock.blocks", "tfc:smooth/granite");
    public static final CreativeTabs CT_ROCK_ITEMS = new CT("rock.items", "tfc:ore/tetrahedrite");
    public static final CreativeTabs CT_WOOD = new CT("wood", "tfc:wood/log/pine");
    public static final CreativeTabs CT_DECORATIONS = new CT("decorations", "tfc:wall/cobble/granite");
    public static final CreativeTabs CT_METAL = new CT("metal", "tfc:metal/ingot/bronze");
    public static final CreativeTabs CT_GEMS = new CT("gems", "tfc:gem/diamond");
    public static final CreativeTabs CT_POTTERY = new CT("pottery", "tfc:mold/axe_head/bronze");
    public static final CreativeTabs CT_MISC = new CT("misc", "tfc:wand");

    public static void init()
    {
        Arrays.stream(field_78032_a).filter(CT.class::isInstance).map(CT.class::cast).forEach(CT::loadIconStack);
    }

    private static class CT extends CreativeTabs
    {
        private final ResourceLocation iconResourceLocation;
        private ItemStack iconStack;

        private CT(String label, String icon)
        {
            super(MOD_ID + "." + label);

            iconResourceLocation = new ResourceLocation(icon);
        }

        @Override
        public ItemStack func_78016_d()
        {
            return iconStack;
        }

        private void loadIconStack()
        {
            //noinspection ConstantConditions
            iconStack = new ItemStack(ForgeRegistries.ITEMS.getValue(iconResourceLocation));
            if (iconStack.func_190926_b())
            {
                TerraFirmaCraft.getLog().error("No icon stack for creative tab {}", func_78013_b());
                iconStack = new ItemStack(Items.field_151055_y);
            }
        }
    }
}
